/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource['epages.io.file']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.io.file'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.io.File $Revision: 1.23 $

*/
dojo.provide('epages.io.file');


epages.io.File = function() {
	this.files = [];
};

epages.io.File.prototype = {

	boundary: (new Date()).getTime().toString(16), 	// Integer - boundary is hex presentation of timestamp

	// encoding: Object
	//    supported encodings for file transfer, RAW should not be used, due to a bug in
	//    the XMLHTTPRequest object
	encoding: {
		RAW:              undefined,
		BASE64:           'base64',
		QUOTEDPRINTABLE:  'quoted-printable',
		XHR:              'epages-xhr'
	},

	clear: function () {
		this.files = [];
	},

	addFile: function (/*String*/formElement, /*String*/fileName, /*String*/fileContent, /*String?*/encoding) {
		// summary:
		//    Adds a file for upload.
		// formElement: name of the form element
		// fileName: name of the file
		// fileContent: contents of the file;
		this.files.push({
			"file":             fileName,
			"name":             formElement,
			"content":          fileContent,
			"contentType":      "application/octet-stream; charset=utf-8",
			"transferEncoding": encoding != null ? this.encoding[encoding] : this.encoding.BASE64
		});
	},
	
	_getFilePost: function() {
		var post = '';
		for( var i=0,iLength=this.files.length ; i<iLength ; i++ ) {
			var file = this.files[i];
			post += "--" + this.boundary + "\r\n"
						+ 'Content-Disposition: form-data; name="' + file.name + '"; filename="' + file.file + '"\r\n'
						+ 'Content-Type: ' + file.contentType + '\r\n';
			if (file.transferEncoding != '') {
				post += 'Content-Transfer-Encoding: ' + file.transferEncoding + "\r\n";
			}
			post += "\r\n" + file.content + "\r\n";
		}
		post += "--" + this.boundary + "--\r\n";
		return post;
	},

	send: function (/*String*/url) {
		// summary:
		//    uploads file via multipart post and returns the result document.
		// example:
		//  | fileUploader = new epages.io.File();
		//  | fileUploader.addFile("NewFile", "test.txt", "This is a test.");
		//  | result = fileUploader.send('http://www.mydomain.de/form.php');
		var outerData = {};
		dojo.rawXhrPost({
			file:       this.files,
			url:        url,
			sync:       true,
			multipart:  true,
			error:      epages.io.Json.prototype.defaultErrorCallback,
			load:       function(data){ outerData.data = dojo.fromJson(data); },
			headers:    { 
				'Accept':       'text/x-json',
				'Content-Type': 'multipart/form-data; boundary=' + this.boundary
			},
			postData:   this._getFilePost()
		});
		return outerData; // Object
	}
};

}

if(!dojo._hasResource["epages.uploader"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.uploader"] = true;
/*
  Copyright (c) 2006-2010, ePages GmbH
  All Rights Reserved.

  uploader.js
  epages.upload $Revision: 1.35 $
*/

dojo.provide("epages.uploader");











(function(){

  var _cache = {};

  epages.Uploader = {
    // HTML skeleton snippet to be inserted into the upload dialog
    _DIALOG_TEMPLATE:
  '<div class="Uploader">\
      <div class="FileListContainer"><div class="HideElement"></div></div>\
      <table class="ContentList UploadAddLinkContainer">\
        <tbody>\
          <tr class="NewEntry">\
            <td class="AlignCenter" colspan="2">\
              <span class="UploadAddLink DoActionLink EnableHover">\
                <span class="BigUploadLink">\
                  <i class="Sprite (%add_button_class%)"></i>\
                  <span>(%text_choose_files%)</span>\
                </span>\
                <span class="HideElementSoft SmallUploadLink">\
                  <i class="Sprite (%add_button_class%)"></i>\
                  <span>(%text_add_more_files%)</span>\
                </span>\
              </span>\
            </td>\
          </tr>\
        </tbody>\
      </table>\
      <div class="UploadFormContainer HideElement"></div>\
    </div>\
    <div class="DialogMessage MessageInfo TopMargin HideElement"></div>\
  </div>',

    // template parsed version of _DIALOG_TEMPLATE
    _PARSED_DIALOG_TEMPLATE: 					"",

    // translate string constants
    _DIALOG_TITLE:										"",
    //_SELECT_LINK_LABEL:								"",
    //_SELECT_LINK_MORE_LABEL:							"",
    _UPLOAD_BUTTON_LABEL:								"",
    _CANCEL_BUTTON_LABEL:								"",
    //_CLOSE_BUTTON_LABEL:								"",

    // TODO: translate error codes
    _ERROR_HEADLINE:									"",
    _ERROR_MIMETYPE_NOT_ACCEPT: 						"",
    _MAXCONTENTLENGTH_EXCEEDED_ERROR: 					"",
    _UPLOADSPACE_EXCEEDED_ERROR:      					"",
    _SESSION_ERROR:										"",
    _MAX_PREVIEW_ITEMS:									10,

    // top part of the file list table
    _fileListTopHTML:				"<table class=\"ContentList FileListTable\"><tbody class=\"FileList\">",
    // bottom part of the file list table
    _fileListBottomHTML:		"</tbody></table>",
    // middle part of the file list table represented as array (for the use of join("") later on)
    _fileListHTMLSnippets:	[''],

    // reference to the upload dialog
    _uploadDialog:					null,

    // reference to the node which holds the file list (and the upload <form/> for browsers without binary xhr support)
    _uploadFormContainer:		null,
    // reference to the "add more" link
    _uploadAddLink:					null,
    // reference to the parent node of the "add more" link
    _uploadAddLinkContainer:null,
    // reference to the file list parent
    _fileListContainer:			null,
    // reference to the <input type="file"/> used to select the files
    _uploadInput:						null,

    // array of all files inside the queue
    _uploadCollection:			[],

    // array of all upload responses
    _uploadResponseUploadedFile:			'',

    // array of all files inside the error msg
    _uploadErrorFiles: [],

    // index of the current file to be uploaded
    _uploadIndex:						0,

    // settings of the current Uploader
    _uploadSettings:				{},

    // flags if the uploader is currently in use
    _uploadActive:					false,
    // flags if errors occured on uploading process
    _uploadErrors:					false,

    // equates to "multiple" flag on "settings" object aside from browsers which don't support multiple uploads
    _multipleFileInputEnabled: false,

    // estimated time for a single upload process (will be calculated precisely later on)
    _uploadTimeEstimation:	200,
    // date object used to calculate the estimated upload time
    _uploadOldTime:					null,
    // reference to the node which represents the upload status in percent
    _uploadOldPercentageBar:null,
    // reference the the dojo animation used to smoothly represent the upload status
    _statusBarAni:					null,

    _resetUploadSettings: function(uploadSettings /* Object */) {
      // summary:
      //	set the default settings object for this instance
      // description:
      //	this is called on startup too to initially fill the settings object

      uploadSettings = uploadSettings || {};
      this._uploadSettings = {
        action:      uploadSettings.action || "?ChangeAction=UploadFiles&ObjectID=" + epages.vars.ObjectID,
        directory:   uploadSettings.directory || null,
        multiple:    uploadSettings.multiple ? epages.string.toBoolean(uploadSettings.multiple) : false,
        fileType:    uploadSettings.fileType || "",
        reloadPage:  uploadSettings.reloadPage ? epages.string.toBoolean(uploadSettings.reloadPage) : false,
        callback:    uploadSettings.callback || function() {},
        formElement: uploadSettings.formElement || "NewFile",
        id:          uploadSettings.id || "uploadAppletNodeID",
        acceptGroup: uploadSettings.acceptGroup || '*/*',
        accept:      uploadSettings.acceptGroup ? epages.mimetype.getGroup(uploadSettings.acceptGroup).join(',') : (uploadSettings.accept || '*/*')
      };

      // fix any "amp;"s
      this._uploadSettings.action = this._uploadSettings.action.replace(/&amp;/,'&');

      // we need this in every case since there is no use of text/x-json as a result of a <form/>.submit()
      if(!this._uploadSettings.action.match(/handleashtml/)) {
        this._uploadSettings.action += "&handleashtml=1";
      }

      // default changeaction
      if(!this._uploadSettings.action.match(/ChangeAction/)) {
        this._uploadSettings.action += "&ChangeAction=UploadFiles";
      }

      // default for viewaction
      if(!this._uploadSettings.action.match(/ViewAction/)) {
        this._uploadSettings.action += "&ViewAction=JSONViewResponse";
      }

      if(this._uploadSettings.directory) {
        this._uploadSettings.action += "&Directory=" + this._uploadSettings.directory;
      }
    },

    _initUploadButton: function() {
      // summary:
      //	init the status of disabled for the upload button
      (this._uploadCollection.length ? dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild,'Disabled') : dojo.addClass(this._uploadDialog.innerButtonBarNode.firstChild,'Disabled') );

    },

    _showUploadDialog: function() {
      // summary:
      //	wrapper around the native show method of the modaldialog widget

      if(this._uploadDialog) {
        this._uploadDialog.show();
      }
    },

    _hideUploadDialog: function() {
      // summary:
      //	wrapper around the native hide method of the modaldialog widget

      if(this._uploadDialog) {
        this._uploadDialog.hide();
      }
    },

    _repositionUploadDialog: function() {
      // summary:
      //	wrapper around the native show method of the modaldialog widget

      if(this._uploadDialog) {
        this._uploadDialog.layout();
      }
    },

    _maximizeUploadArea: function() {
      // summary:
      //	show the big file selection link (NewEntry area)

      dojo.removeClass(dojo.query(".BigUploadLink", this._uploadAddLink)[0], "HideElementSoft");
      dojo.addClass(dojo.query(".SmallUploadLink", this._uploadAddLink)[0], "HideElementSoft");
    },

    _minimizeUploadArea: function() {
      // summary:
      //	show the tiny file selection link (NewEntry area)

      dojo.addClass(dojo.query(".BigUploadLink", this._uploadAddLink)[0], "HideElementSoft");
      dojo.removeClass(dojo.query(".SmallUploadLink", this._uploadAddLink)[0], "HideElementSoft");
    },

    _cleanUp: function(uploadSettings) {
      // summary:
      //	reset all predefined variables
      // description:
      //	this emulates the constructor since epages.Uploader is called and not instantiated via "new"
      uploadSettings = uploadSettings || this._uploadSettings;

      this._resetUploadSettings(uploadSettings);
      if(this._uploadFormContainer) {
        this._fileListHTMLSnippets = [''];
        this._uploadErrorFiles = [];
        this._uploadCollection = [];
        this._uploadResponseUploadedFile = '';
        this._uploadIndex = 0;
        this._uploadActive = false;
        this._uploadErrors = false;
        this._uploadFormContainer.innerHTML = this._fileListContainer.innerHTML = "<div class=\"HideElement\"></div>";
        dojo.removeClass(this._fileListContainer.parentNode, "FilesSelected");
        dojo.removeClass(this._uploadAddLinkContainer, "HideElement");
        dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild, "Active");
        dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild, "Disabled");
        this._maximizeUploadArea();
      }
    },

    _onSubmitUploadDialog: function(evt) {
      // summary:
      //	start the uploading process (mapped to "click" event)

      if(dojo.hasClass(evt.currentTarget, "Disabled")) {
        return;
      }

      dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild, "Active");
      dojo.addClass(this._uploadDialog.innerButtonBarNode.firstChild, "Disabled");
      dojo.addClass(this._uploadAddLinkContainer, "HideElement");

      this._uploadOldTime = new Date();
      this._uploadActive = true;
      this._uploadNextQueueItem();
    },

    _uploadNextQueueItem: function() {
      // summary:
      //	recursively upload one file after another
      this._updateProgressDisplay();

      // we're uploading the file list in reversed order (top > bottom)
      var file = this._uploadCollection[this._uploadIndex].srcFile;

      if(this._multipleFileInputEnabled) {
        // xhr upload
        var xhr = new XMLHttpRequest(); // a plain xhr object because dojo can't handle binary requests at all
        xhr.open("POST", this._uploadSettings.action);
        xhr.setRequestHeader("Content-Type", "application/octet-stream");
        xhr.setRequestHeader("If-Modified-Since", "Mon, 26 Jul 1997 05:00:00 GMT");
        xhr.setRequestHeader("Cache-Control", "no-cache");

        var contentDisposition = "attachment; ";
        contentDisposition += "filename=\"" + encodeURIComponent(file.fileName || file.name)  + "\"";
        var formElementName = this._uploadSettings.formElement;
        if(formElementName) {
          contentDisposition += "; name=\"" + encodeURIComponent(formElementName)  + "\"";
        }
        xhr.setRequestHeader("content-disposition", contentDisposition);

        if(xhr.sendAsBinary) {
          xhr.sendAsBinary(file.getAsBinary());
        }else {
          xhr.send(file);
        }
        dojo.connect(xhr, "readystatechange", function() { // listening to "onprogress" would be better but is very / too hard to normalize by now
          if(xhr.readyState === 4) {
            epages.Uploader._onResponse(xhr.responseText);
          }
        });
        dojo.connect(xhr, "error", this, "_onResponse");
      }
      else {
        // "classic" upload via <form/>.submit()
        this._uploadFormContainer.innerHTML = "";

        var fileUploadForm = document.createElement("form");
        fileUploadForm.action = this._uploadSettings.action;
        fileUploadForm.method = "POST";
        fileUploadForm.enctype = fileUploadForm.encoding = "multipart/form-data";
        fileUploadForm.target = "fileUploadFrame";
        this._uploadFormContainer.appendChild(fileUploadForm);

        var uploadFrameContainer = document.createElement("div");
        uploadFrameContainer.innerHTML = "<iframe name=\"fileUploadFrame\" onload=\"epages.Uploader._onResponse(this.contentWindow.document.body.innerHTML)\"></iframe>";
        this._uploadFormContainer.appendChild(uploadFrameContainer);

        fileUploadForm.appendChild(file);

        fileUploadForm.submit();
      }
    },

    _updateProgressDisplay: function() {
      // summary:
      //	making the uploading process endurable while showing some nice animations

      var tdNode = this._fileListContainer.getElementsByTagName("tr")[this._uploadIndex+(this._uploadErrorFiles.length ? 1 : 0)].firstChild;

      var statusBar = dojo.query("div.StatusBar", tdNode.parentNode)[0];
      var percentageBar = dojo.query("div.InnerStatusBar > div", statusBar)[0];

      if(this._statusBarAni) {
        this._statusBarAni.stop();
        this._uploadOldPercentageBar.style.width = (statusBar.offsetWidth - 2) + "px";
      }

      this._statusBarAni = dojox.fx.wipeTo({node: percentageBar, width: statusBar.offsetWidth - 2, duration: this._uploadTimeEstimation, easing: dojo.fx.easing.quadIn});
      this._statusBarAni.play();

      var currentDate = new Date();
      this._uploadTimeEstimation = ~~((currentDate - this._uploadOldTime) / 2);
      this._uploadOldTime = currentDate;
      this._uploadOldPercentageBar = percentageBar;

    },

    _throwError: function(errorText /* String */, trEntry /* <tr/> Node */) {
      // summary:
      //	an error occured for a specific upload item

      this._uploadErrors = true;
      var percentageBar = dojo.query(".StatusBar div.InnerStatusBar div", trEntry)[0];
      percentageBar.className = "PercentageCritical";

      // TODO: show some sort of error message
      //top.dojo.publish("uimessage/show", [ "", errorText, "Dialog" , {titleBar: this._ERROR_HEADLINE, typeClass: "Error", sizeClass:"Large"}]);
    },

    _onResponse: function(responseSnippet /* ? */) {
      // summary:
      //	upload finished for a specific file and we (maybe) received a server response

      responseSnippet = responseSnippet || ""; // be sure that it will never be undefined
      var response;

      var trEntry = this._fileListContainer.getElementsByTagName("tr")[this._uploadIndex];

      try {
        // there is a chance that we receive garbage which can't be transformed into an JSON object
        // with that in mind there is no way around the try/catch statement
        response = eval("[" + responseSnippet + "]")[0];
      }catch(e) {}

      if(!response) {
        // hard error
        dojo.addClass(trEntry, "UploadError");
        if(responseSnippet.match("file is too large")) {
          this._throwError(this._MAXCONTENTLENGTH_EXCEEDED_ERROR, trEntry);
        }else {
          //outdated session, false token, something else happened
          this._throwError(this._SESSION_ERROR, trEntry);
        }
        this._uploadActive = false; // stop polling
      } else if(response.Errors) {
        // soft error
        if(response.Errors[0].Message == "FeatureLimitExceeded") {
          this._throwError(this._UPLOADSPACE_EXCEEDED_ERROR, trEntry);
        } else {
          this._throwError(response.Errors[0].Message, trEntry);
        }
        dojo.addClass(trEntry, "UploadError");
        //this._uploadActive = false; // stop polling
      } else {
        // success
        dojo.addClass(trEntry, "UploadSuccess");

        if( response.uploadedFile ) {
          this._uploadResponseUploadedFile = response.uploadedFile;
        }
      }

      this._uploadIndex++;
      if(this._uploadIndex < this._uploadCollection.length && this._uploadActive) {
        this._uploadNextQueueItem();
      }else {
        this._onUploadFinished(response);
      }

      if(trEntry.nextSibling) {
        this._fileListContainer.scrollTop = trEntry.nextSibling.offsetTop - this._fileListContainer.offsetHeight + trEntry.nextSibling.offsetHeight;
      }
    },

    _onUploadFinished: function(response) {
      // summary:
      //	all files are uploaded - now show the user the results and sum it up
      //if(this._uploadErrors) {
        // TODO: show some sort of error message to sum it up and provide a button for closing the dialog the soft way (not via "abort");
      //} else {
      if( this._uploadErrors ) {
        var errorList = [];
        dojo.query(".UploadError", this._fileListContainer).forEach( function( node, i ){
          errorList.push( node.childNodes[1].childNodes[0].nodeValue );
          console.log({log: node.childNodes[1].childNodes[0] });
        });

        alert( this._ERROR_MIMETYPE_NOT_ACCEPT +'\n\n'+ errorList.join('\n') );
      }

        this._hideUploadDialog();
        this._uploadSettings.callback();
        if(this._uploadSettings.reloadPage) {
          var dialogArea = actualDialogArea ? "DialogArea=" + actualDialogArea : "";
          if(location.href.search(/Monitor/) != -1 && epages.vars.BaseUrl && epages.vars.ViewAction && epages.vars.ObjectID){
            var newHref = epages.vars.BaseUrl + '?ViewAction=' + epages.vars.ViewAction + '&ObjectID=' + epages.vars.ObjectID;
            if(dialogArea == ''){
              location.href = newHref;
            }else{
              location.href = newHref + '&'+dialogArea;
            }
          }
          else{
            if(location.href.search(/DialogArea/) != -1){
              var newLocation;
              if (this.useBaseUrlForHref) {
                newLocation = epages.vars.BaseUrl + '?ViewAction=' + epages.vars.ViewAction + '&ObjectID=' + epages.vars.ObjectID;
              } else {
                newLocation = location.href;
              }
              for( var i=0,iLength=epagesDialog.areaName.length ; i<iLength ; i++ ){
                var regEx = new RegExp('DialogArea='+epagesDialog.areaName[i]);
                newLocation = newLocation.replace(regEx,dialogArea);
              }
              location.href = newLocation;
            }else{
              if(dialogArea == ''){
                location.href = location.href;
              }else {
                location.href = location.href + '&'+dialogArea;
              }
            }
          }
        }

        response.uploadedFile = this._uploadResponseUploadedFile;

        dojo.publish(this._uploadSettings.id + '/onUploadFinished', [ response ]);
      //}
    },

    _onCancelUploadDialog: function() {
      // summary:
      //	user pressed "cancel" on the upload dialog

      this._uploadActive = false;
      this._hideUploadDialog();
    },

    _removeFileListRow: function( event, i ) {
      // summary:
      //	remove a file from queue
      var tr = (event.target || event.srcElement).parentNode.parentNode.parentNode;
      var tbody = tr.parentNode;
        tbody.removeChild( tr );

      this._uploadCollection.splice(i,1);
      this._fileListHTMLSnippets.splice(i,1);
      this._refreshZebra();
      this._addDeleteConnects();
      this._initUploadButton();
    },

    _refreshZebra: function() {
      // summary:
      //	refresh alternate color style for table
      var table = this._fileListContainer.childNodes[0].childNodes;
      var trs;
      for( var i=0,l=table.length ; i<l ; i++ ) {
        if( table[i].nodeName == 'TBODY' ){
          trs = table[i].childNodes;
        }
      }
      for( var i=0,l=trs.length ; i<l ; i++ ) {
        if( i % 2) {
          dojo.addClass( trs[i], 'alternate' );
        }
        else {
          dojo.removeClass( trs[i], 'alternate' );
        }
      }
    },

    _addDeleteConnects: function() {
      // summary:
      //	connect a remove event for all remove buttons

      this._deleteHandles = this._deleteHandles || [];

      dojo.forEach(this._deleteHandles, dojo.disconnect);

      var list = dojo.query('a.FileDelete',this._fileListContainer);

        for( var i=0,l=list.length ; i<l ; i++ ) {

          var node = list[i];
          var index = i;

          this._deleteHandles.push(
            dojo.connect( node, 'click', this, function(event) {
              this._removeFileListRow( event, index ) ;
            } )
          );
        }
    },

    _addFileListRow: function( file /* Hash */) {
      // summary:
      //	add a representation of a selected file to the file list

      var snippet = ["<tr" + ((this._fileListHTMLSnippets.length % 2) ? " class=\"alternate\"" : "" ) + "><td class=\""];
      var dict = epages.io.dictionary.translation;
      var translationRemove = dict.get("Remove");

      snippet.push("\"><i class=\"Sprite NoPadding " + file.icon + "\"></i>");
      snippet.push("</td><td>" + file.name + "<div class=\"StatusBar\"><div class=\"InnerStatusBar\"><div class=\"PercentageNormal\" style=\"width:0\"></div></div></div><a href=\"javascript:;\" class=\"FileDelete\" style=\"position: absolute; right: 10px; margin-top: -20px\"><i class=\"Sprite ico_s_remove\" title=\"" + translationRemove + "\"></i></a></td></tr>");

      this._fileListHTMLSnippets.push(snippet.join(""));
    },

    _addFileToUploadQueue: function(file /* file binary */) {
      // summary:
      //	attach a file to be uploaded to the internal upload list

      this._uploadCollection.push(file);
    },

    _addFileErrorRow: function() {
      // summary:
      //	add error msg to FileList
      var length = this._uploadErrorFiles.length;
      if( length > 0 ) {
        var snippet = ['<tr class="ErrorDialog"><td><i class="Sprite NoPadding ico_m_error"></i></td><td>'];
        snippet.push( this._ERROR_MIMETYPE_NOT_ACCEPT +  '<br />' );
        for( var i=0 ; i<length ; i++ ) {
          snippet.push( this._uploadErrorFiles[i] + '<br />' );
        }
        snippet.push('</td></tr>');
        this._fileListHTMLSnippets[0] = snippet.join('');
      }
      else {
        this._fileListHTMLSnippets[0] = '';
      }
    },

    _addFileToErrorList: function(fileName) {
      // summary:
      //	add file with wrong mimetype to error list
      this._uploadErrorFiles.push(fileName);
    },

    _mimetypeHandle: function(srcFile) {
      // summery:
      //   check the mimetype of the file
      var file = {
          srcFile: srcFile
        };
      if( srcFile.value ) {
        file.name = srcFile.value.match(":") ? srcFile.value.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/)[2] : srcFile.value;
        file.type = null;
        file.size = null;
      }
      else {
        file.name = srcFile.name || srcFile.fileName;
        file.type = srcFile.type || srcFile.fileType;
        file.size = srcFile.size || srcFile.fileSize;
      }

      if( file.type ) {
        var instance = new epages.Mimetype(file.type);
      }
      else {
        var instance = new epages.Mimetype();
        file.type = instance.setBySuffix( file.name.substring(file.name.lastIndexOf('.')+1) ).getMime();
      }

      file.allowed = instance.isGroup( this._uploadSettings.acceptGroup );
      file.preview = instance.isPreviewable();
      file.icon = instance.getIcon();

      return file;
    },

    _appendToQueue: function(fileInput /* <input type="file"/> */) {
      // summary:
      //	queue one or more files selected via <input type="file"/>

      // only one file may be selected but the user selected another one
      // so we delete the previous file selection
      if(!this._uploadSettings.multiple) {
        this._cleanUp();
      }

      dojo.addClass(this._fileListContainer.parentNode, "FilesSelected");

      if(fileInput.files) {
        this._multipleFileInputEnabled = true;
        dojo.forEach(fileInput.files, function(file, fileIndex) {
          file = this._mimetypeHandle(file);
          if( file.allowed && (file.size ? file.size/1024 < epages.vars.MaxContentLength ? true : false : true) ) {
            this._addFileListRow(file);
            this._addFileToUploadQueue(file);
          }
          else {
            this._addFileToErrorList(file.name);
          }
        }, this);

      }
      else {
        // i.e. "C:\"
        // the local path is part of the fileAlias (Windows fake path, i.e. "C:\fakepath\ico_64hover_featurepacks_orgRGB.png").
        // We only want the name of the file: (C:\fakepath)[\](ico_64hover_featurepacks_orgRGB.png)
        //fileAlias = fileInput.value.match(":") ? fileInput.value.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/)[2] : fileInput.value;
        var file = this._mimetypeHandle(fileInput);



        if( file.allowed ) {
          this._addFileListRow(file);
          this._addFileToUploadQueue(file);
        }
        else {
          this._addFileToErrorList(file.name);
        }
      }

      fileInput.value='';

      this._initUploadButton();
      this._addFileErrorRow();
      this._fileListContainer.innerHTML = this._fileListTopHTML + this._fileListHTMLSnippets.join("") + this._fileListBottomHTML;
      this._minimizeUploadArea();
      this._insertUploadInput();

      this._addDeleteConnects();

    },

    _queueFiles: function( uploadInput ) {
      // summary:
      //	queue one or more files selected via <input type="file"/> with a certain delay and hide the upload dialog beforehand
      setTimeout(
        dojo.hitch(
          this,
          function() {
            // TODO: _appendToQueue can take a long a time with > 50 files selected at once - we need some sort of becalmer animation for the user
            this._appendToQueue( uploadInput && uploadInput.nodeName ? uploadInput : this._uploadInput );
            setTimeout(
              dojo.hitch(
                this,
                function() {
                  this._repositionUploadDialog();
                  this._fileListContainer.scrollTop = 0;
                }
              ),
              this._uploadDialog.duration);
          }
        ),
        this._uploadDialog.duration + 10);
    },

    _insertUploadInput: function() {
      // summary:
      //	create a <input type="file"/>
      // description:
      //	the created file input will reside on top of the "add more" link on which the user will think he clicks on
      if(this._uploadInput) {
        this._uploadInput.parentNode.removeChild(this._uploadInput);
      }
      this._uploadInput = document.createElement("input");
      this._uploadInput.type = "file";
      this._uploadInput.name = this._uploadSettings.formElement;
      this._uploadInput.accept = this._uploadSettings.accept;
      if(this._uploadSettings.multiple) {
        // this._uploadInput.multiple = true < won't work
        this._uploadInput.setAttribute("multiple", "true");
      }
      this._uploadInput.className = "UploadInputOverlay";
      this._uploadAddLink.appendChild(this._uploadInput);
      dojo.connect(this._uploadInput, "change", this, "_queueFiles");
    },

    _buildDialog: function() {
      // summary:
      //	build up the upload dialog

      var dlgParams = {
        title : this._DIALOG_TITLE,
        width : 450,
        scroll: "hidden",
        content: this._PARSED_DIALOG_TEMPLATE,
        buttons: [{
          label: this._UPLOAD_BUTTON_LABEL,
          onclick: dojo.hitch(this, this._onSubmitUploadDialog)
        },{
          label: this._CANCEL_BUTTON_LABEL,
          onclick: dojo.hitch(this, this._onCancelUploadDialog)
        }]
      };

      if(this._uploadDialog) {
        // update dialog content
        this._fileListContainer = undefined;
        this._uploadDialog.setupContent(dlgParams);
      }
      else {
        this._uploadDialog = new epages.widget.Modaldialog({
          options:{
            title : dlgParams.title,
            width : dlgParams.width,
            scroll: dlgParams.scroll,
            content: dlgParams.content
          },
          buttons: dlgParams.buttons
        });
        dojo.body().appendChild(this._uploadDialog.domNode);
      }
    },

    _mapNodes: function() {
      // summary:
      //	build up references the the importand and most used dialog nodes

      if(this._fileListContainer) {
        return;
      }
      var innerNode = this._uploadDialog.domNode;
      this._fileListContainer = dojo.query(".FileListContainer", innerNode)[0];
      this._uploadFormContainer = dojo.query(".UploadFormContainer", innerNode)[0];
      this._uploadAddLink = dojo.query(".UploadAddLink", innerNode)[0];
      this._uploadAddLinkContainer = dojo.query(".UploadAddLinkContainer", innerNode)[0];
    },

    _applyTranslations: function() {
      // summary:
      //	replaces member variables with caption texts with its correct translation strings
      var dict = epages.io.dictionary.translation;
      var translation = function(string) {
          return _cache[string] = _cache[string] || dict.get(string);
        };

      var uploadText = this._uploadSettings.multiple ? translation("FileUploadMultiple") : translation("FileUploadSingle");

      var templatedDialog = $TMPL(this._DIALOG_TEMPLATE, {
        add_button_class 		: 'ico_s_add',
        text_choose_files 	: uploadText+'...',
        text_add_more_files : this._uploadSettings.multiple ? translation("AddMoreImagesLink") : translation("AddMoreImagesLink")
      }, false);
      this._PARSED_DIALOG_TEMPLATE = templatedDialog.generateOutput();

      this._DIALOG_TITLE = uploadText;
      this._UPLOAD_BUTTON_LABEL = uploadText;
      this._CANCEL_BUTTON_LABEL = translation("Cancel");
      this._MAXCONTENTLENGTH_EXCEEDED_ERROR = translation("FileSizeLimitError");
      this._UPLOADSPACE_EXCEEDED_ERROR = translation("FeatureLimitExceeded");
      this._SESSION_ERROR = translation("InternalServerError");
      this._ERROR_HEADLINE = translation("FileUploadError");
      this._ERROR_MIMETYPE_NOT_ACCEPT = translation("MimetypeNotAcceptError");
    },

    open: function(uploadSettings /* Object */) {
      // summary:
      //	open an upload dialog
      // example:
      //	| onclick="epages.Uploader.open({multiple:true, directory:'#Directory', reloadPage:true})"

      // only one Uploader dialog at once may be active
      // and we have to assume that is was opened before
      this._hideUploadDialog();
      this._cleanUp(uploadSettings);
      this._applyTranslations();
      this._buildDialog();
      this._mapNodes();
      this._insertUploadInput();
      this._maximizeUploadArea();
      this._showUploadDialog();
      this._initUploadButton();
    },

    directOpen: function( node /* node */, uploadSettings /* Object */ ) {
      // summary:
      //	open an upload dialog direct onchange of fileInput
      // example:
      //  | <input type="file" onchange="epages.Uploader.directOpen( this, {directory:'#Directory', reloadPage:true} )" formaction="?ChangeAction=..." multiple="true" />
      //
      // only one Uploader dialog at once may be active
      // and we have to assume that is was opened before

      this.open(uploadSettings);
      this._queueFiles( node );
    }

  };

})();

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.UploadImage"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.UploadImage"] = true;
/*
  Copyright (c) 2006-2007, ePages GmbH
  All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.UploadImage");









(function(jq){

var jqUploaderReady = !1,
  jqUploaderCreate = function( self ){
    var o = {
        url:		self.url,
        data: {
          ViewAction:			'JSONViewResponse',
          ChangeAction:		self.uploadAction,
          ObjectID:			self.objectId,
          Image:				self.fileAttribute,
          UseMediaGallery:	self.useMediaGallery ? 1 : 0
        },
        accept:		self.fileType,
        callback:	self.reloadPage ? '?ViewAction='+ep.config.viewAction+'&ObjectID='+ep.config.objectId : function( data ){
          dojo.publish( self.uploadAppletNode.id + '/onUploadFinished', [data[0].success || data[0].ERROR || {}] );
        }
      };

    if(self.saveAfterUpload){
      o.callback = function( data ){
        dojo.publish( self.uploadAppletNode.id + '/onUploadFinished', [data[0].success || data[0].ERROR || {}] );
      }
    }

    if( self.doScaleImage ){
      if( self.scaleWidth != '' ){ o.data.Width	= self.scaleWidth; }
      if( self.scaleHeight != '' ){ o.data.Height	= self.scaleHeight; }
      if( self.scaleQuality != '' ){ o.data.Quality = self.scaleQuality; }
    }

    de_epages(self.uploadAppletNode).presentationUiUploader(o);
  };

dojo.declare(
  "epages.cartridges.de_epages.presentation.widget.UploadImage",
  [epages.widget.DeleteFileOnServer, epages.widget.LocalizedWidget ],
  {
    imageWidth :        '',
    imageHeight:        '',
    scaleWidth :        '',
    scaleHeight:        '',
    scaleQuality:       '',
    uploadAction:       'UploadFiles',
    fileType:           'image/*',
    infoText:           '',
    scaleText:          '',
    doScaleImage:       '1',
    onUploaded:         '',
    templateString:     '',
    templateString:"<div>\n  <table class=\"FullWidth\" style=\"border:0\"><tr><td style=\"border:0;width:100px;\">\n    <span dojoAttachPoint=\"displayNode\" dojoType=\"epages.widget.Slides\" imageHeight=\"100px\" imageWidth=\"100px\" stopped=\"true\" showControls=\"false\" showMisc=\"false\" showDescription=\"false\">\n      <ins image=\"${filePath}\"></ins>\n    </span>\n    <span class=\"ToolTip ep-js\" data-js=\".uiTooltip({})\">\n      <div dojoAttachPoint=\"nameNode\" class=\"Bold\">${fileName}</div>\n      <div dojoAttachPoint=\"infoNode\">${infoText}</div>\n    </span>\n  </td>\n  <td style=\"border:0;\">\n    <div class=\"LeftMargin\" style=\"height:100px;position:relative\">\n      <input type=\"file\" class=\"NoButtonTrigger\" dojoAttachpoint=\"uploadAppletNode\"/>\n      <div class=\"ClearLeft\"></div>\n      <div dojoAttachPoint=\"scaleImageNode\" class=\"TopSmallMargin\">\n        <input dojoAttachPoint=\"scaleCheckBoxNode\" type=\"text\" name=\"${scaleCheckboxName}\" id=\"ResizeImageLarge_${id}\" value=\"1\" class=\"Checkbox NoButtonTrigger\" />\n        <label for=\"ResizeImageLarge_${id}\">${scaleText}</label>\n      </div>\n      <div dojoAttachPoint=\"additionalInfoNode\">${additionalInfo}</div>\n    </div>\n  </td></tr>\n  <tr>\n    <td colspan=\"2\">\n      <span\n    dojoType=\"epages.widget.DeleteFileOnServer\"\n    dojoAttachPoint=\"deleteNode\"\n    fileAttribute=\"${fileAttribute}\"\n    filePath=\"${filePath}\"\n    fileName=\"${fileName}\"\n    confirm=\"${confirm}\"\n    objectId=\"${deleteObjectId}\"\n    changeAction=\"${deleteAction}\"\n    altDelete=\"${deleteActionName}\"\n    ></span>\n    </td>\n  </tr>\n  </table>\n</div>\n",
    translationName:    dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget','templates/translation'),
    widgetsInTemplate:  true,
    useMediaGallery:    false,
    fileAttribute:      '',
    fileInputNode:      null,
    fileInputName:      '',
    fileInputValue:     '',
    uploadInputName:    'NewFile',
    _scaleCheckBox:		null,
    scaleCheckboxName:  'ResizeImageLarge',
    showDeleteNode:     true,
    objectId:			epages.vars.ObjectID || '',
    deleteObjectId:		this.objectId || epages.vars.ObjectID || '',
    saveAfterUpload:    false,
    url:                '?',
    saveAction:         'Save',
    saveParameters:     undefined,
    reloadPage:			false,
    deleteAction:		'DeleteFile',
    deleteActionName:	'',

    headlineConfirm:    epages.io.dictionary.get('HeadLineDeleteFile'), // 'Moechten Sie diese Datei wirklich loeschen ?',
    titleConfirm:       epages.io.dictionary.get('TitleDeleteFile'), // 'Datei loeschen',
    altDelete:          epages.io.dictionary.get('TitleDeleteFile'), //'Datei loeschen',
    additionalInfo:     '',

    setUploadUrl: function () {
      var self = this;

      if( jqUploaderReady ){
          jqUploaderCreate( self );
      }
      else{
        jq.ready( 'de_epages.presentation.ui.uploader', function(){
          jqUploaderCreate( self );
          jqUploaderReady = !0;
        });
      }
    },

    postMixInProperties: function () {
      this.inherited("postMixInProperties", arguments);

      this.doScaleImage = epages.string.toBoolean(this.doScaleImage);
      this.useMediaGallery = epages.string.toBoolean(this.useMediaGallery);
      this.fileName = epages.format.slice(this._getFileName(this.fileName), 25);
      this.showDeleteNode = epages.string.toBoolean(this.showDeleteNode);
      if (!this.fileAttribute && this.fileInputName) {
        this.fileAttribute = this.fileInputName;
      }

      // build info text
      this.infoText = '';
      if (this.fileSize != '') {
        this.infoText = epages.localize.formatBytes(this.fileSize, 0);
      }
      if (this.imageWidth != '' && this.imageHeight != '') {
        this.infoText += ' (' + this.imageWidth + ' &times; ' + this.imageHeight + 'px)';
      }

      // build scale text
      if (!this.scaleText) {
        this.scaleText = this.translate('ScaleImage');
      }
      if (this.scaleWidth != '' && this.scaleHeight != '') {
        this.scaleText += "<br /><span class='AdditionalInfo' style='padding-left:22px'>(" + this.translate("maxWidth") + " " + this.scaleWidth + "px &times; " + this.translate("maxHeight") +" "+ this.scaleHeight + "px)</span>";
      } else if(this.scaleWidth) {
        this.scaleText += "<br /><span class='AdditionalInfo' style='padding-left:22px'>(" + this.translate("Width") + ": " + this.scaleWidth + "px)</span>";
      } else if(this.scaleHeight) {
        this.scaleText += "<br /><span class='AdditionalInfo' style='padding-left:22px'>(" + this.translate("Height") + ": " + this.scaleHeight + "px)</span>";
      }
    },

    postCreate: function() {
      this.inherited("postCreate", arguments);
      if (!this.scaleWidth && !this.scaleHeight) {
        this.scaleImageNode.style.display = 'none';
      }
      if (!this.infoText) {
        this.infoNode.style.display = 'none';
      }
      if (!this.additionalInfo) {
        this.additionalInfoNode.style.display = 'none';
      }
      if (!this.showDeleteNode || !this.filePath || !this.fileName) {
        this.deleteNode.domNode.style.display = 'none';
      }
      this._scaleCheckBox = new epages.widget.FormElement({}, this.scaleCheckBoxNode);
      this.scaleCheckBoxNode = this._scaleCheckBox.elementNode;
      if (this.doScaleImage) {
        this._scaleCheckBox.attr('checked',true);
      }
      this.connect(this.scaleCheckBoxNode, "onclick", "toggleDoScale");

      if (this.fileInputName) {
        this.fileInputNode = this.domNode.ownerDocument.createElement('input');
        this.fileInputNode.type = 'hidden';
        this.fileInputNode.name = this.fileInputName;
        this.fileInputNode.value = this.fileInputValue;
        this.domNode.appendChild(this.fileInputNode);
        if(this.saveAfterUpload){
          dojo.addClass(this.fileInputNode, 'NoButtonTrigger');
        }
      }

      // set id for uploader
      dojo.attr(this.uploadAppletNode, 'id', this.id+'_uploader');
      dojo.attr(this.uploadAppletNode, 'name', this.uploadInputName);
      dojo.subscribe(this.uploadAppletNode.id + "/onUploadFinished", this, 'onUpload');
      if (this.showDeleteNode) {
        this.deleteNode.onSuccess = dojo.hitch(this, 'onDelete');
      }

      // build url
      this.setUploadUrl();
    },

    onOpen: function (evt) {
      dojo.stopEvent(evt);
      
      if (this.onPreview == '') {
        openWindow(this.filePath, '', 'open');
        return false;
      }
      return eval(this.onPreview);
    },

    toggleDoScale:function (evt) {
      this.doScaleImage = !this.doScaleImage;
      this.setUploadUrl();
    },

    onUpload: function (opt) {
      var self = this;

      if (this.onUploaded != '') {
        eval(this.onUploaded);
      }
      if( opt.uploadedFile ){
        var image = opt.uploadedFile.toString();
        if(image) {
          this.displayNode.addImage({image: image}, true);
        }
        if (this.fileInputNode) {
          this.fileInputValue = opt.uploadedObjectFile ? opt.uploadedObjectFile : image;
          this.fileInputNode.value = this.fileInputValue;
          epages.event.fire(this.fileInputNode, 'change');
        }
        var imageInfo = opt.imageInfo ? opt.imageInfo : null;
        if (imageInfo) {
          this.filePath = image;
          this.fileName = imageInfo.FileName;
          this.nameNode.innerHTML = imageInfo.FileName;
          this.nameNode.href = image;
          this.infoNode.innerHTML = epages.localize.formatBytes(imageInfo.Size, 0) + ' (' + imageInfo.Width + ' &times; ' + imageInfo.Height +'px)';
          this.infoNode.style.display = '';
          // update file in deletenode
          if(this.deleteNode) {
            this.deleteNode.filePath=image;
                this.deleteNode.fileName=imageInfo.FileName;
              }
        } else {
          this.fileName = this._getFileName(image);
          this.nameNode.innerHTML = this.fileName;
          // update file in deletenode
          if(this.deleteNode) {
            this.deleteNode.filePath = this._getFilePath(image);
                this.deleteNode.fileName = this.fileName;
              }
        }
        this.nameNode.style.display = '';
        this.infoNode.style.display = '';
        if (this.showDeleteNode) {
          this.deleteNode.domNode.style.display = '';
        }
        if(this.saveAfterUpload){
          // move method call to other thread
          setTimeout(function(){
            self._saveAfterUpload();
          },1);
        }
        if( window.pageCache_SetStatus ){
          pageCache_SetStatus(true);
        }
        dojo.publish(this.id + '/upload');
      }
    },

    onDelete: function() {
      this.nameNode.style.display = 'none';
      this.infoNode.style.display = 'none';
      this.removeImage();
      if (this.fileInputNode) {
        this.fileInputValue = '';
        this.fileInputNode.value = '';
        epages.event.fire(this.fileInputNode, 'change');
      }
      dojo.publish(this.id + '/delete');
    },

    removeImage: function() {
      // summary:
      //    set empty image (hide the current image)
      this.displayNode.addImage({image: epages.vars.IconsRoot + "/general_img_transparentpixel.gif"}, true);
    },

    _getFileName: function(path) {
      return path.split('/').pop();
    },

    _getFilePath: function(path) {
      path = path.split('/').pop();
      return path.join('/');
    },

    _saveAfterUpload: function(){
      //summary: save Attribute direct after Upload
      var json = new epages.io.Json;
      var parameters = {
        'ViewAction': 'JSONViewResponse',
        'ObjectID':   this.objectId,
        'ChangeAction':    this.saveAction
      };
      parameters[this.fileInputName] = this.fileInputValue;
      if(this.saveParameters){
        dojo.mixin(parameters,this.saveParameters);
      }

      json.loadAsync(this.url,
      dojo.hitch(this,function(result){
        if(!result.error){
          this.deleteNode.fileName = this.fileName;

          // if location must be reloaded
          if(this.reloadPage){
            location.href = '?ViewAction='+ep.config.viewAction+'&ObjectID='+ep.config.objectId;
          }
        }

      }),parameters);
    }

  }
);

})(jQuery);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.FilenameInput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.FilenameInput"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.widget.FilenameInput");



dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.FilenameInput",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * dojo widget properties
		 */
		widgetsInTemplate  : true,
		templateString     : '',
		templateType       : 'normal',
		defaultTemplateType: 'normal',
		templateString:"<table class=\"InnerGrid FilenameInput\"><tr><td class=\"NoPadding\">\n  <span>${filepath}</span>\n  <label dojoAttachPoint=\"nodeTitle\" class=\"Bold\">${filename}</label>\n  <input type=\"text\" dojoAttachPoint=\"nodeInputTitle\" value=\"${filename}\" class=\"HideElementSoft\"/>\n  <i class=\"Sprite ico_s_pencil LinkImage\" dojoAttachPoint=\"noteEditButton\" title=\"{EditFileName}\"></i>\n  <span>${fileext}</span>\n  <input type=\"hidden\" dojoAttachPoint=\"nodeHiddenName\" name=\"${inputname}\" value=\"${filename}\" />\n  <span dojoAttachPoint=\"nodeInputTitleWidthCalculator\" class=\"HideElementSoft\"></span>\n</td></tr></table>\n",
		translationName    : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget','templates/translation'),

		/**
		 * private properties
		 */
		_currentValue      : '',

		/**
		 * public properties
		 */
		filepath					 : '',
		filename					 : '',
		fileext						 : '',
		inputname					 : '',
		showAsInput				 : false,
		markAsError				 : false,

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			// append slash
			if(this.filepath) {
				this.filepath += '/';
			}
		},

		postCreate: function() {
			// summary: Connect to the file name text / input events.
			// description: Connects to the user events for click, blur and keyup. Adds events for
			//		the file name text and the file name input as well as for the little edit icon.
			this.inherited("postCreate", arguments);
			// use the FormElement widget
			nodeInputTitle = new epages.widget.FormElement({}, this.nodeInputTitle).elementNode;
			// change name events
			this.connect(this.nodeTitle,      'click', '_onClickItem');
			this.connect(this.nodeInputTitle, 'blur', '_onLeaveItem');
			this.connect(this.noteEditButton, 'click', '_onClickImage');
			this.connect(this.nodeInputTitle, 'keyup', '_onKeyUp');
			this.connect(this.nodeInputTitle, 'change', '_adjustInputWidth');

			// show the input field instead of the text from the beginning,
			// i.e. when the template caught an FormError
			if(this.showAsInput) {
				this._onClickItem();
				setTimeout(dojo.hitch(this, function() {
					this._adjustInputWidth();
				}), 1);

			}
			// add dialog error, i.e. when the template caught an FormError
			if(this.markAsError) {
				dojo.addClass(this.nodeInputTitle,"DialogError");
			}
		},

		_onKeyUp: function(evt) {
			// summary: Care for DialogError if error present and Copy input value to hidden input.
			// description: Mark dialog field as erroneous if empty value. Copy the updated input
			//		value to the hidden input field.
			if(!this.nodeInputTitle.value){
				dojo.addClass(this.nodeInputTitle,"DialogError");
			} else {
				dojo.removeClass(this.nodeInputTitle,"DialogError");
				if (evt.keyCode == dojo.keys.ENTER) {this._selectItem()}
			}
			this.nodeHiddenName.value = this.nodeInputTitle.value;
			this._adjustInputWidth();
		},

		_onClickImage: function(evt) {
			// summary: Handler for click event on the small edit pen icon.
			// description: Executes same action as click on the filename text does.
			this._onClickItem();
			dojo.stopEvent(evt);
		},

		_onClickItem: function() {
			// summary: Change the file name text span into an input field.
			// description: Hides the file name text and shows a input field with the filename instead.
			this._currentValue = this.filename;
			this._adjustInputWidth();

			if(!this.markAsError) {
				dojo.removeClass(this.nodeInputTitle,"DialogError");
			}
			dojo.addClass(this.nodeTitle, "HideElementSoft");
			dojo.removeClass(this.nodeInputTitle, "HideElementSoft");
			dojo.removeClass(this.nodeInputTitle.parentNode, "HideElementSoft");
			dojo.addClass(this.noteEditButton, "HideElementSoft");

			this.nodeInputTitle.focus();
			this.nodeInputTitle.select();

			setTimeout(dojo.hitch(this, function() {
				this.nodeInputTitle.removeAttribute("focused");
				this.nodeInputTitle.className += '';
			}), 1);
		},

		_onLeaveItem: function() {
			// summary: Event handler for leaving the file name input field.
			// description: If the input value did nit change, hide the file name input field and show
			//		the file name text again. If the value in the input field has changed, keep the input
			//		field and mark it as changed.
			if(this._currentValue == this.nodeInputTitle.value && !this.markAsError) {
				// nothing changed, so hide the input again
				dojo.addClass(this.nodeInputTitle, "HideElementSoft");
				dojo.removeClass(this.nodeTitle, "HideElementSoft");
				dojo.removeClass(this.noteEditButton, "HideElementSoft");
			}
		},

		_adjustInputWidth: function() {
			// summary: Adjust the width of the input element.
			// description: The input width will be recalculated as the user types in a new value.
			this.nodeInputTitleWidthCalculator.innerHTML = this.nodeInputTitle.value || this._currentValue;
			this.nodeInputTitle.style.width = this.nodeInputTitleWidthCalculator.offsetWidth + 10 + "px";
		}

	}
);

}

