/*global define*/
define('de_epages/externalcontent/gadgetdialog/externalvideo-view', [
    'jquery',
    './config-view',
    './constants',
    '$tmpl!./externalvideo-view',
    '$dict!../dictionary',

    '../ui/externalvideo' // The gadget to configure.
], function ($, ConfigView, CONSTANTS, template, dict) {
    'use strict';

    var regexToProvider = {
        'youtu': 'youtube',
        'myvideo': 'myvideo',
        'vimeo': 'vimeo',
        'dailymotion': 'dailymotion',
        'wideo': 'wideofr',
        'metacafe': 'metacafe'
    },
        providerToIdRegex = {
            'youtube': /v=([\w\-]+)|be\/([\w\-]+)|embed\/([\w\-]+)/,
            'myvideo': /watch\/([\w\-]+)/,
            'vimeo': /vimeo\.com\/?[video]*?\/([\w\-]+)/,
            'dailymotion': /video\/([\w\-]+)/,
            'wideofr': /wideo\.fr\/video\/([\w\-]+)/,
            'metacafe': /watch\/([\w\-]+\/[\w\-]+)/
        },
        providerRegex = /youtu|myvideo|vimeo|dailymotion|wideo|metacafe/,
        getVideoTypeAndId = function (urlembedString) {

            var videoProvider = providerRegex.exec(urlembedString),
                video,
                i;
/* not testable because the access to the inserted iframe is blocked */
//#JSCOVERAGE_IF false
            if (videoProvider && videoProvider.length) {
                videoProvider = regexToProvider[videoProvider[0]];
                video = providerToIdRegex[videoProvider].exec(urlembedString);
                if (video && video.length) {
                    i = 1;
                    if (videoProvider === 'youtube') {
                        while (video[i] === undefined && i < video.length - 1) {
                            i = i + 1;
                        }
                    }
                    return {
                        'provider': videoProvider,
                        'id': video[i]
                    };
                }
            }
        };
//#JSCOVERAGE_ENDIF

    return ConfigView.extend({

        alias: 'externalvideo',

        template: template,

        dict: dict,

        events: {
            'submit form': 'onSubmit', // See *config-view*.
            'change input[type!="radio"][name!="video"]': 'onInput', // See *config-view*.
            'change input[name="video"]': 'onVideoInput'
        },

        // overwrite addAdditionalGadgetOptions method inherited from config-view.js
        addAdditionalTemplateOptions: function(tmplOptions){
            var provider = tmplOptions.provider ? tmplOptions.provider : undefined;

            // if an URL is stored in the constants (constants.js)
            if(provider && CONSTANTS.gExternalVideoUrl[provider]){
                // extend template options with the found video URL
                $.extend(tmplOptions, {videourl: CONSTANTS.gExternalVideoUrl[provider]});
            }
        },

        onVideoInput: function (e) {

            var target = e.target,
                typeAndId = getVideoTypeAndId(target.value);

            this.elements.verifyingUrl.removeClass('fail-icon success-icon');
/* reason: see above */
//#JSCOVERAGE_IF false
            if (typeAndId) {
                this.setOptions(typeAndId);
                this.renderPreview();
                this.elements.verifyingUrl.addClass('success-icon');
//#JSCOVERAGE_ENDIF
            } else {
                this.setOptions({
                    'type': '',
                    'id': ''
                });
                this.renderPreview();
                this.elements.verifyingUrl.addClass('fail-icon');
            }
        }
    });
});