/*globals define, ep*/

define([
    'testsuite/qunit',
    'jquery',
    'ep',
    'ep/ajax',
    './tray',
    '$ready!'
], function (QUnit, $, ep) {
    'use strict';

    var fixture = $('#qunit-fixture'),
        tray,
        data = {
            "tableHead": [{
                "isSortable": 0,
                "name": "",
                "id": "ObjectID",
                "isSelectable": 1
            }, {
                "isSortable": 1,
                "name": "Product number",
                "id": "Alias",
                "isSelectable": 0
            }, {
                "isSortable": 1,
                "name": "",
                "id": "NameOrAlias",
                "isLinkable": 1,
                "isSelectable": 0
            }, {
                "isSortable": 0,
                "name": "",
                "id": "VariationAttr",
                "isSelectable": 0
            }, {
                "isSortable": 1,
                "name": "List price",
                "id": "ListPrice",
                "isSelectable": 0
            }],
            "totalNumber": "22",
            "orderBy": "NameOrAlias",
            "lastPage": 2,
            "orderDesc": 0,
            "tableContent": {
                "1": [{
                    "Alias": "be_40401",
                    "Parents": [],
                    "ObjectID": 17144,
                    "VariationAttr": null,
                    "NameOrAlias": "Berghaus Paclite Jacket - Men",
                    "hasSubTable": 1,
                    "ListPrice": "199.95 €"
                }, {
                    "Alias": "be_40402",
                    "Parents": [],
                    "ObjectID": 17156,
                    "VariationAttr": null,
                    "NameOrAlias": "Berghaus Paclite Jacket - Women",
                    "hasSubTable": 1,
                    "ListPrice": "199.95 €"
                }, {
                    "Alias": "vs_3202112018",
                    "Parents": [],
                    "ObjectID": 17215,
                    "VariationAttr": null,
                    "NameOrAlias": "Black Bear Gemini",
                    "ListPrice": "29.95 €"
                }, {
                    "Alias": "cg_0101004270",
                    "Parents": [],
                    "ObjectID": 17137,
                    "VariationAttr": null,
                    "NameOrAlias": "Camping AZ CV270 valve gas canister",
                    "ListPrice": "3.95 €"
                }, {
                    "Alias": "cg_0101104470",
                    "Parents": [],
                    "ObjectID": 17138,
                    "VariationAttr": null,
                    "NameOrAlias": "Camping AZ CV470 valve Gas canister",
                    "ListPrice": "7.95 €"
                }, {
                    "Alias": "de_3201212002",
                    "Parents": [],
                    "ObjectID": 17212,
                    "VariationAttr": null,
                    "NameOrAlias": "Deuter Hydro 2.0",
                    "ListPrice": "74.95 €"
                }, {
                    "Alias": "de_3203104010",
                    "Parents": [],
                    "ObjectID": 17213,
                    "VariationAttr": null,
                    "NameOrAlias": "Deuter Kangaroo",
                    "ListPrice": "99.95 €"
                }, {
                    "Alias": "de_3206199010",
                    "Parents": [],
                    "ObjectID": 17216,
                    "VariationAttr": null,
                    "NameOrAlias": "Deuter Teddy Bear",
                    "ListPrice": "26.95 €"
                }, {
                    "Alias": "er_7142303001",
                    "Parents": [],
                    "ObjectID": 17139,
                    "VariationAttr": null,
                    "NameOrAlias": "Edelrid Black Bear Rope",
                    "ListPrice": "1.45 €"
                }],
                "2": [{
                    "Alias": "be_40401",
                    "Parents": [],
                    "ObjectID": 17144,
                    "VariationAttr": null,
                    "NameOrAlias": "Berghaus Paclite Jacket - Men",
                    "hasSubTable": 1,
                    "ListPrice": "199.95 €"
                }, {
                    "Alias": "be_40402",
                    "Parents": [],
                    "ObjectID": 17156,
                    "VariationAttr": null,
                    "NameOrAlias": "Berghaus Paclite Jacket - Women",
                    "hasSubTable": 1,
                    "ListPrice": "199.95 €"
                }]
            }
        },
        _ajax = ep.ajax;

    ep.ajax = function (o) {
        if (o.data.ObjectID) {
            return {
                done: function (f) {
                    f(data);
                }
            };
        }

        return _ajax(o);
    };

    QUnit.module("de_epages/presentation/ui/tray", {
        setup: function () {
            tray = $('<button type="button">Add Elements</button>').appendTo(fixture);

            tray.presentationUiTray({
                smartSearchString: 'Test',
                tabs: {
                    'products': {
                        id: 'view1',
                        name: 'products',
                        additionalContent: '<input type="checkbox" name="checkboxAdditionalContent" />',
                        action: 'JSONInsertFromProducts'
                    }
                }
            });

            QUnit.strictEqual(
                typeof tray.data('uiPresentationUiTray'),
                'object',
                'Check if widget is created'
            );
        },
        teardown: function () {
            tray.presentationUiTray('destroy');

            QUnit.strictEqual(
                tray.data('uiPresentationUiTray'),
                undefined,
                'Check if widget is destroyed'
            );

            tray.remove();
        }
    });

    QUnit.test('Check uiTray widget\'s methods', 2 + 2, function () {
        $.each(['_create', 'destroy'], function () {
            QUnit.ok(
                $.isFunction($.ui.presentationUiTray.prototype[this]),
                'Check if ' + this + ' is a method of the tray widget'
            );
        });
    });

    QUnit.test('Check if widget is created', 1 + 2, function () {
        tray.trigger('click');

        QUnit.strictEqual(
            $('.ep-tray-dialog').length,
            1,
            'Check if dialog was created after click on button'
        );
    });
});